git
===

Add the relevant files to make your package compliant with Git_ versioning system.

This option takes care of the local package side of git. If you wish to host your
code on a distant server, consider using the :doc:`../github/main` or
:doc:`../gitlab/main` option.

Modifications
-------------

.. raw:: html
    :file: modifications.html



.. _Git: https://git-scm.com/
